<?php

global $reports_text;
$reports_text = array (

'summary'       =>  'Zusammenfassung',

'changelog'     =>  'Changelog',
'changeloggen'  =>  'Changelog Generator',
'listfrom'      =>  'Liste der Änderungen von',
'to'            =>  'bis',
'show'          =>  'Zeigen',
'oldestfirst'   =>  'Älteste zuerst',
'recentfirst'   =>  'Aktuellste zuerst',

'severity'      =>  'Schweregrad',
'severityrep'   =>  'Schwerebericht',
'totalopen'     =>  'Offene Aufgaben gesamt',

'age'           =>  'Alter',
'agerep'        =>  'Altersbericht',

'eventsrep'     =>  'Ereignisbericht',
'events'        =>  'Ereignisse',
'tasks'         =>  'Aufgaben',
'opened'        =>  'Geöffnet',
'closed'        =>  'Geschlossen',
'edited'        =>  'Geändert',
'assigned'      =>  'Zugeteilt',
'comments'      =>  'Kommentare',
'attachments'   =>  'Anhänge',
'relatedtasks'  =>  'Verwandte Aufgaben',
'notifications' =>  'Benachrichtigungen',
'reminders'     =>  'Erinnerungen',
'within'        =>  'Während',

'pastday'       =>  'des letzten Tages',
'pastweek'      =>  'der letzten Woche',
'pastmonth'     =>  'des letzten Monats',
'pastyear'      =>  'des letzten Jahres',
'nolimit'       =>  'Unbegrenzt',

'from'          =>  'Von',
'duein'         =>  'Fällig in',

'date'          =>  'Zeitraum',

);
?>
